**Your pull request has been merged and a preview build has been published!**

Build {{ .version }} is now available at TestPyPI: <https://test.pypi.org/project/bcamp-dl/{{ .version }}>

To install, run: `pip install -i https://test.pypi.org/simple/ bcamp-dl=={{ .version }}`

Note that not all dependencies can be resolved via TestPyPI.
